matrix
A sparse vector of vectors.
Usage
matrix()Parameters
data: Iterable = ()
Attributes
| Name | Description |
|---|---|
| T | Return matrix with reversed dimensions. |
| col | COO format column index array of the matrix |
| data | COO format data array of the matrix |
| row | COO format row index array of the matrix |
T
Return matrix with reversed dimensions.
T=property(transpose)
col
COO format column index array of the matrix
col: np.ndarray
data
COO format data array of the matrix
data: np.ndarray
row
COO format row index array of the matrix
row: np.ndarray
Methods
| Name | Description |
|---|---|
| filter() | Return matrix with function applies across vectors. |
| fromcoo() | Return matrix from COOrdinate format arrays. |
| map() | Return matrix with function applies across vectors. |
| sum() | Return sum of matrix elements across axis, by default both. |
| transpose() | Return matrix with reversed dimensions. |
| update() | Update from mapping or iterable. |
filter()
Return matrix with function applies across vectors.
Usage
filter(func, *args, **kwargs)fromcoo()
Return matrix from COOrdinate format arrays.
Usage
fromcoo(row, col, data)map()
Return matrix with function applies across vectors.
Usage
map(func, *args, **kwargs)sum()
Return sum of matrix elements across axis, by default both.
Usage
sum(axis=None)transpose()
Return matrix with reversed dimensions.
Usage
transpose()update()
Update from mapping or iterable.
Usage
update(data)